Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(79)

Unified Diff: chromeos/geolocation/simple_geolocation_provider.h

Issue 2624843003: Add support for cellular geolocation (Closed)
Patch Set: Update device tests to use correct dict key Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chromeos/geolocation/simple_geolocation_provider.h
diff --git a/chromeos/geolocation/simple_geolocation_provider.h b/chromeos/geolocation/simple_geolocation_provider.h
index 2b7ded2f8adaccc4bdab1eb7361618ed83f28f13..b4fddcc50b2dcee7492687f047fac21b5ec6a1f5 100644
--- a/chromeos/geolocation/simple_geolocation_provider.h
+++ b/chromeos/geolocation/simple_geolocation_provider.h
@@ -36,10 +36,12 @@ class CHROMEOS_EXPORT SimpleGeolocationProvider {
virtual ~SimpleGeolocationProvider();
// Initiates new request. If |send_wifi_access_points|, WiFi AP information
// will be added to the request. See SimpleGeolocationRequest for the
// description of the other parameters.
void RequestGeolocation(base::TimeDelta timeout,
bool send_wifi_access_points,
+ bool send_cell_towers,
SimpleGeolocationRequest::ResponseCallback callback);
// Returns default geolocation service URL.
« no previous file with comments | « chrome/browser/resources/options/browser_options.js ('k') | chromeos/geolocation/simple_geolocation_provider.cc » ('j') | no next file with comments »
@@ -36,10 +36,12 @@ class CHROMEOS_EXPORT SimpleGeolocationProvider {
virtual ~SimpleGeolocationProvider();
// Initiates new request. If |send_wifi_access_points|, WiFi AP information
- // will be added to the request. See SimpleGeolocationRequest for the
- // description of the other parameters.
+ // will be added to the request, similarly for |send_cell_towers| and Cell
+ // Tower information. See SimpleGeolocationRequest for the description of
+ // the other parameters.
void RequestGeolocation(base::TimeDelta timeout,
bool send_wifi_access_points,

Powered by Google App Engine
This is Rietveld 408576698